/**
 *
 * Copyright 2020 Tencent
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
import { Plugin, PluginServiceApi } from '@cloudbase/framework-core';
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
export interface IFrameworkPluginAuthInputs {
    configs: IAuthConfig[];
}
export interface IAuthConfig {
    /**
     * 登录平台
     */
    platform: 'NONLOGIN' | 'ANONYMOUS';
    /**
     * 开通状态
     */
    status: 'ENABLE' | 'DISABLE';
    /**
     * 登录平台的 AppID，选填
     */
    platformId: string;
    /**
     * 登录平台的 AppSecret，选填
     */
    platformSecret: string;
}
declare class AuthPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginAuthInputs;
    protected resolvedInputs: IFrameworkPluginAuthInputs;
    protected buildOutput: any;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginAuthInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 生成SAM文件
     */
    compile(): Promise<{
        Config: {
            Login: {
                Platform: "NONLOGIN" | "ANONYMOUS";
                PlatformId: string;
                PlatformSecret: string;
                Status: "ENABLE" | "DISABLE";
            }[];
        };
    }>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
}
export declare const plugin: typeof AuthPlugin;
export {};
//# sourceMappingURL=index.d.ts.map